=== modified file '.bzrignore'
--- .bzrignore	2006-07-04 14:00:29 +0000
+++ .bzrignore	2006-07-13 05:09:23 +0000
@@ -23,3 +23,9 @@
 ./.shelf
 # Mac droppings
 .DS_Store
+# win32 installer generated files
+./doc/*.htm
+./doc/bzr_man.txt
+./py2exe.log
+./tools/win32/bzr.iss
+./dist

=== modified file 'Makefile'
--- Makefile	2006-06-20 03:57:11 +0000
+++ Makefile	2006-06-29 09:15:47 +0000
@@ -30,5 +30,51 @@
 TAGS: $(tag_files)
 	ctags-exuberant -e $(tag_files)
 
-tutorial.html: tutorial.txt
-	rest2html tutorial.txt > tutorial.html
+
+# make bzr.exe for win32 with py2exe
+exe:
+	@echo Make bzr.exe
+	setup.py py2exe > py2exe.log
+	copy /Y tools\win32\start_bzr.bat win32_bzr.exe\start_bzr.bat
+	copy /Y tools\win32\bazaar.url win32_bzr.exe\bazaar.url
+
+# translate txt docs to html
+doc_dir := doc 
+txt_files := $(wildcard $(addsuffix /*.txt, $(doc_dir)))
+htm_files := $(patsubst %.txt, %.htm, $(txt_files)) doc/bzr_man.htm
+
+%.htm: %.txt
+	rst2html.py --link-stylesheet --stylesheet=default.css $*.txt $*.htm
+
+doc/bzr_man.txt:
+	generate_docs.py -o doc/bzr_man.txt rstx
+
+docs: $(htm_files)
+
+copy_docs: docs
+	copy /Y NEWS win32_bzr.exe\NEWS
+	copy /Y README win32_bzr.exe\README
+	python tools/win32/copy_docs.py
+
+# win32 installer for bzr.exe
+installer: exe copy_docs
+	@echo Make windows installer
+	cog.py -d -o tools\win32\bzr.iss tools\win32\bzr.iss.cog
+	"C:\Program Files\Inno Setup 5\iscc" /Q tools\win32\bzr.iss
+
+# win32 python's distutils-based installer
+# require to have python interpreter installed on win32
+python-installer:
+	python setup.py bdist_wininst --target-version=2.4 --title="Bazaar-NG" --install-script="bzr-win32-bdist-postinstall.py"
+
+
+# clean on win32 all installer-related files and directories
+clean_win32:
+	if exist build rmdir /S /Q build
+	if exist win32_bzr.exe rmdir /S /Q win32_bzr.exe
+	if exist py2exe.log del /Q py2exe.log
+	if exist doc\*.htm del /Q doc\*.htm
+	if exist doc\bzr_man.txt del /Q doc\bzr_man.txt
+	if exist tools\win32\bzr.iss del /Q tools\win32\bzr.iss
+	if exist bzr-setup*.exe del /Q bzr-setup*.exe
+	if exist dist rmdir /S /Q dist

=== added file 'bzr.ico'
Binary files bzr.ico and bzr.ico differ
=== modified file 'bzrlib/doc/api/__init__.py'
--- bzrlib/doc/api/__init__.py	2006-06-06 08:09:09 +0000
+++ bzrlib/doc/api/__init__.py	2006-06-29 08:41:31 +0000
@@ -28,7 +28,11 @@
 import os
     
 def test_suite():
-    candidates = os.listdir(os.path.dirname(__file__))
+    dir_ = os.path.dirname(__file__)
+    if os.path.isdir(dir_):
+        candidates = os.listdir(dir_)
+    else:
+        candidates = []
     scripts = [candidate for candidate in candidates
                if candidate.endswith('.txt')]
     return doctest.DocFileSuite(*scripts)

=== modified file 'bzrlib/tests/test_setup.py'
--- bzrlib/tests/test_setup.py	2006-05-05 01:15:53 +0000
+++ bzrlib/tests/test_setup.py	2006-06-29 08:41:31 +0000
@@ -32,8 +32,10 @@
 
     def test_build(self):
         """ test cmd `python setup.py build`
-        
-        This typically catches new subdirectories which weren't added to setup.py
+
+        This test ensure that build process run correct.
+        Ensure that man generator works correct.
+        Also can catches new subdirectories which weren't added to setup.py
         """
         self.log('test_build running in %s' % os.getcwd())
         try:

=== modified file 'doc/configuration.txt'
--- doc/configuration.txt	2006-06-16 15:59:24 +0000
+++ doc/configuration.txt	2006-06-29 08:41:31 +0000
@@ -1,3 +1,9 @@
+=======================
+Bazaar-NG configuration
+=======================
+
+Information on how to configure Bazaar-NG.
+
 Location of configuration file
 ==============================
 Each user gets a pair of configurations files in $HOME/.bazaar. The first

=== added file 'doc/default.css'
--- doc/default.css	1970-01-01 00:00:00 +0000
+++ doc/default.css	2006-06-29 08:41:31 +0000
@@ -0,0 +1,142 @@
+/* from John Arbash Meinel's `Short tutorial' */
+
+body {
+  background-color: #ffffff;
+  color: #303030;
+  margin-top: 50px;
+  margin-left: 50px;
+  margin-right: 50px;
+  margin-bottom: 70px;
+  font-family: Verdana, Geneva, Arial, sans-serif;
+  font-size: small;
+  line-height: 180%
+  }
+
+/* p {
+  text-indent: 3em
+} */
+
+h1.title {
+  text-align: center;
+  color: #000000;
+  font-family: Georgia, "Time New Roman", Times, serif;
+  font-size: 1.8em;
+  }
+
+
+div.contents p {
+  font-weight: bold;
+  }
+
+div.contents p a:hover {
+  color: inherit;
+  }
+
+h1 {
+  color: #b52b2b; 
+  /* DKREDcolor: #966b72; */
+  /* GREY color: #444444; */
+  font-family: Georgia, "Time New Roman", Times, serif;
+  font-size: 1.5em;
+  }
+
+h1 a:link {
+  color: inherit;
+  }
+  
+h1 a:hover {
+  color: inherit;
+  }
+
+h1 a:visited {
+  color: inherit;
+  }
+
+h2 {
+  color: #222;
+  /* RED color: #966b72; */
+  text-decoration: underline;
+  font-family: Georgia, "Time New Roman", Times, serif;
+  font-size: 1.4em;
+  }
+
+h2 a:link {
+  color: inherit;
+  }
+
+h2 a:hover {
+  color: inherit;
+  }
+
+h2 a:visited {
+  color: inherit;
+  }
+
+h3 {
+  color: #966b72; 
+  /* color: #966b72; */
+  font-family: Georgia, "Time New Roman", Times, serif;
+  }
+
+h3 a:link {
+  color: inherit;
+  }
+
+h3 a:hover {
+  color: inherit;
+  }
+
+h3 a:visited {
+  color: inherit;
+  }
+
+dt {
+  color: #000000;
+  font-weight: bold;
+  }
+/*
+  border: 4px solid blue;
+  padding: 1ex;
+  background: #7777FF;
+        }
+dt:hover 
+  {
+  background-color: black;
+  }
+dt:active
+  {
+  background-color: red;
+  }
+*/
+
+tt {
+  color: #000000;
+  font-weight: normal;
+  font-family: "Lucida", "Monaco", "Courier", Monospace;
+  }
+
+.literal-block {
+  margin-left: 5em;
+  color: #000000;
+  font-weight: normal;
+  font-family: "Lucida", "Monaco", "Courier", Monospace;
+  background-color: #c1d1ff;
+  background-color: #e5ecf9;
+  border: 1px solid #888888;
+  padding: 1em;
+  }
+
+a:link {
+  color: #4c52ff;
+  text-decoration: none;
+  }
+
+a:visited {
+  color: #4c53ff;
+  text-decoration: none;
+  }
+
+a:hover {
+  color: #b52727;
+  text-decoration: none;
+  }

=== added file 'doc/index.txt'
--- doc/index.txt	1970-01-01 00:00:00 +0000
+++ doc/index.txt	2006-06-29 08:41:31 +0000
@@ -0,0 +1,42 @@
+=========
+Bazaar-NG
+=========
+-------------------
+Documentation index
+-------------------
+
+These documents originally came from the Bazaar-NG wiki hosted at
+http://bazaar-vcs.org. The documents on the wiki take precedence 
+in the event of a discrepancy between what is documented here 
+and what is documented on the wiki.
+
+
+* `Tutorial <tutorial.htm>`_
+
+    Explains how to use bzr. Loaded with examples.
+
+* `Configuration <configuration.htm>`_
+
+    Information on how to configure Bazaar-NG
+
+* `Setting up email <setting_up_email.htm>`_
+
+    The various ways that exist to tell Bazaar-NG your email address for
+    commits
+
+* `Plugins <plugins.htm>`_
+    
+    Information on how to use plugins in Bazaar-NG
+
+* `Specifying revision <specifying_revisions.htm>`_
+
+    Description of the subarguments for ``-r`` as used by commands such as
+    **bzr log** and **bzr merge**
+
+* `Using aliases <using_aliases.htm>`_
+
+    How to setup and use command aliases.
+
+This document automatically created based on output of **bzr help**:
+
+* `Man page (help for bzr commands) <bzr_man.htm>`_

=== modified file 'doc/plugins.txt'
--- doc/plugins.txt	2006-03-14 16:57:35 +0000
+++ doc/plugins.txt	2006-06-29 08:41:31 +0000
@@ -1,3 +1,9 @@
+=================
+Bazaar-NG plugins
+=================
+
+Information on how to use plugins in Bazaar-NG.
+
 What is a Plugin
 ================
 A plugin is an external component for Bazaar-NG that is typically made by

=== modified file 'doc/setting_up_email.txt'
--- doc/setting_up_email.txt	2006-06-29 23:26:31 +0000
+++ doc/setting_up_email.txt	2006-07-13 05:09:23 +0000
@@ -1,3 +1,10 @@
+================
+Setting up email
+================
+
+The various ways that exist to tell Bazaar-NG your email address for
+commits.
+
 Why set up an email address with Bazaar-NG?
 ===========================================
 Bazaar-NG stores the claimed email address in revisions when they're

=== modified file 'doc/specifying_revisions.txt'
--- doc/specifying_revisions.txt	2006-03-14 16:57:35 +0000
+++ doc/specifying_revisions.txt	2006-06-29 08:41:31 +0000
@@ -1,3 +1,10 @@
+================================
+Specifying revision in Bazaar-NG
+================================
+
+Description of the subarguments for ``-r`` as used by commands such as
+**bzr log** and **bzr merge**.
+
 Revision specs and ranges
 =========================
 

=== modified file 'doc/using_aliases.txt'
--- doc/using_aliases.txt	2006-03-14 16:57:35 +0000
+++ doc/using_aliases.txt	2006-06-29 08:41:31 +0000
@@ -1,4 +1,8 @@
-Command aliases are an eay way to customize the behaviour of Bazaar-NG. Aliases
+====================================
+Using aliases for Bazaar-NG commands
+====================================
+
+Command aliases are an easy way to customize the behaviour of Bazaar-NG. Aliases
 are an easy way to create shortcuts for commonly-typed commands, or to set
 defaults for commands.
 

=== modified file 'generate_docs.py'
--- generate_docs.py	2006-02-13 01:28:03 +0000
+++ generate_docs.py	2006-06-29 08:41:31 +0000
@@ -38,7 +38,13 @@
 import tools.doc_generate
 
 def main(argv):
-    parser = OptionParser(usage="%prog [options] OUTPUT_FORMAT")
+    parser = OptionParser(usage="""%prog [options] OUTPUT_FORMAT
+
+Available OUTPUT_FORMAT:
+
+    man              man page
+    rstx             man page in ReStructuredText format
+    bash_completion  bash completion script""")
 
     parser.add_option("-s", "--show-filename",
                       action="store_true", dest="show_filename", default=False,

=== modified file 'setup.py'
--- setup.py	2006-06-21 13:54:14 +0000
+++ setup.py	2006-06-29 09:15:47 +0000
@@ -1,13 +1,61 @@
 #! /usr/bin/env python
 
-# This is an installation script for bzr.  Run it with
-# './setup.py install', or
-# './setup.py --help' for more options
-
+"""Installation script for bzr.
+Run it with
+ './setup.py install', or
+ './setup.py --help' for more options
+"""
+
+##
+# META INFORMATION FOR SETUP
+
+META_INFO = {'name':         'bzr',
+             'version':      '0.9pre',
+             'author':       'Canonical Ltd',
+             'author_email': 'bazaar-ng@lists.ubuntu.com',
+             'url':          'http://www.bazaar-vcs.org/',
+             'description':  'Friendly distributed version control system',
+             'license':      'GNU GPL v2',
+            }
+
+BZRLIB = {'packages': ['bzrlib',
+                       'bzrlib.benchmarks',
+                       'bzrlib.bundle',
+                       'bzrlib.bundle.serializer',
+                       'bzrlib.doc',
+                       'bzrlib.doc.api',
+                       'bzrlib.export',
+                       'bzrlib.plugins',
+                       'bzrlib.plugins.launchpad',
+                       'bzrlib.store',
+                       'bzrlib.store.revision',
+                       'bzrlib.store.versioned',
+                       'bzrlib.tests',
+                       'bzrlib.tests.blackbox',
+                       'bzrlib.tests.branch_implementations',
+                       'bzrlib.tests.bzrdir_implementations',
+                       'bzrlib.tests.interrepository_implementations',
+                       'bzrlib.tests.interversionedfile_implementations',
+                       'bzrlib.tests.repository_implementations',
+                       'bzrlib.tests.revisionstore_implementations',
+                       'bzrlib.tests.workingtree_implementations',
+                       'bzrlib.transport',
+                       'bzrlib.transport.http',
+                       'bzrlib.ui',
+                       'bzrlib.util',
+                       'bzrlib.util.configobj',
+                       'bzrlib.util.effbot.org',
+                       'bzrlib.util.elementtree',
+                      ],
+         }
+
+
+##
 # Reinvocation stolen from bzr, we need python2.4 by virtue of bzr_man
 # including bzrlib.help
 
-import os, sys
+import os
+import sys
 
 try:
     version_info = sys.version_info
@@ -76,48 +124,70 @@
         import generate_docs
         generate_docs.main(argv=["bzr", "man"])
 
+
 ########################
 ## Setup
 ########################
 
-setup(name='bzr',
-      version='0.9pre',
-      author='Canonical Ltd',
-      author_email='bazaar-ng@lists.ubuntu.com',
-      url='http://bazaar-vcs.org/',
-      description='Friendly distributed version control system',
-      license='GNU GPL v2',
-      packages=['bzrlib',
-                'bzrlib.benchmarks',
-                'bzrlib.doc',
-                'bzrlib.doc.api',
-                'bzrlib.export',
-                'bzrlib.plugins',
-                'bzrlib.plugins.launchpad',
-                'bzrlib.store',
-                'bzrlib.store.revision',
-                'bzrlib.store.versioned',
-                'bzrlib.tests',
-                'bzrlib.tests.blackbox',
-                'bzrlib.tests.branch_implementations',
-                'bzrlib.tests.bzrdir_implementations',
-                'bzrlib.tests.interrepository_implementations',
-                'bzrlib.tests.interversionedfile_implementations',
-                'bzrlib.tests.repository_implementations',
-                'bzrlib.tests.revisionstore_implementations',
-                'bzrlib.tests.workingtree_implementations',
-                'bzrlib.transport',
-                'bzrlib.transport.http',
-                'bzrlib.ui',
-                'bzrlib.util',
-                'bzrlib.util.elementtree',
-                'bzrlib.util.effbot.org',
-                'bzrlib.util.configobj',
-                'bzrlib.bundle',
-                'bzrlib.bundle.serializer'
-                ],
-      scripts=['bzr'],
-      cmdclass={'install_scripts': my_install_scripts, 'build': bzr_build},
-      data_files=[('man/man1', ['bzr.1'])],
-    #   todo: install the txt files from bzrlib.doc.api.
-     )
+if not ('py2exe' in sys.argv):
+    # std setup
+    ARGS = {'scripts': ['bzr'],
+            'data_files': [('man/man1', ['bzr.1'])],
+            # install the txt files from bzrlib.doc.api.
+            'package_data': {'bzrlib': ['doc/api/*.txt']},
+           }
+
+    # for python-based installer we don't need to use custom cmdclasses
+    if not ('bdist_wininst' in sys.argv):
+        ARGS['cmdclass'] = {'build': bzr_build,
+                            'install_scripts': my_install_scripts,
+                           }
+    else:
+        # but need to add postinstall script
+        ARGS['scripts'].append('tools/win32/bzr-win32-bdist-postinstall.py')
+    
+    ARGS.update(META_INFO)
+    ARGS.update(BZRLIB)
+
+    print ARGS
+    
+    setup(**ARGS)
+
+else:
+    # py2exe setup
+    import py2exe
+
+    # pick real bzr version
+    import bzrlib
+
+    version_number = []
+    for i in bzrlib.version_info[:4]:
+        try:
+            i = int(i)
+        except ValueError:
+            i = 0
+        version_number.append(str(i))
+    version_str = '.'.join(version_number)
+
+    target = py2exe.build_exe.Target(script = "bzr",
+                                     dest_base = "bzr",
+                                     icon_resources = [(0,'bzr.ico')],
+                                     name = META_INFO['name'],
+                                     version = version_str,
+                                     description = META_INFO['description'],
+                                     author = META_INFO['author'],
+                                     copyright = "(c) Canonical Ltd, 2005-2006",
+                                     company_name = "Canonical Ltd.",
+                                     comments = META_INFO['description'],
+                                    )
+    options_list = {"py2exe": {"packages": BZRLIB['packages'] +
+                                           ['elementtree'],
+                               "dist_dir": "win32_bzr.exe",
+                              },
+                   }
+    setup(options=options_list,
+          console=[target,
+                   'tools/win32/bzr_postinstall.py',
+                   'tools/bzr_test_dependencies.py',
+                  ],
+          zipfile='lib/library.zip')

=== added file 'tools/bzr_test_dependencies.py'
--- tools/bzr_test_dependencies.py	1970-01-01 00:00:00 +0000
+++ tools/bzr_test_dependencies.py	2006-06-29 08:41:31 +0000
@@ -0,0 +1,73 @@
+# Copyright (C) 2006 by Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""Check third-party libraries used by bzr
+installed for std. python or bundled into bzr.exe
+Written by Alexander Belchenko
+"""
+
+import os
+import sys
+
+# bzr.exe has special flag
+if hasattr(sys, 'frozen'):
+    print 'bzr is frozen:', sys.frozen
+
+# python interpreter
+print 'Python', sys.version
+
+# os id
+print 'System:', (sys.platform, os.name)
+
+# ctypes (for win32)
+try:
+    import ctypes
+    print 'ctypes:', ctypes.__version__
+except ImportError:
+    print 'ctypes: None'
+
+# elementtree
+try:
+    import elementtree.ElementTree
+    print 'ElementTree:', elementtree.ElementTree.VERSION
+    try:
+        import cElementTree
+        print 'cElementTree:', cElementTree.VERSION
+    except ImportError:
+        print 'cElementTree: None'
+except ImportError:
+    print 'ElementTree: None'
+
+# pycurl
+try:
+    import pycurl
+    print 'PyCurl:', pycurl.version
+except ImportError:
+    print 'PyCurl: None'
+
+# paramiko
+try:
+    import paramiko
+    print 'Paramiko:', paramiko.__version__
+except ImportError:
+    print 'Paramiko: None'
+
+# pycrypto
+try:
+    import Crypto
+    print 'PyCrypto:', Crypto.__version__
+except ImportError:
+    print 'PyCrypto: None'

=== modified file 'tools/doc_generate/autodoc_rstx.py'
--- tools/doc_generate/autodoc_rstx.py	2006-04-20 02:52:59 +0000
+++ tools/doc_generate/autodoc_rstx.py	2006-06-29 08:41:31 +0000
@@ -189,7 +189,7 @@
 Files
 =====
 
-**On Linux**:  ``~/.bazaar/bazaar.conf/``
+**On Linux**:  ``~/.bazaar/bazaar.conf``
 
 **On Windows**: ``C:\\Documents and Settings\\username\\Application Data\\bazaar\\2.0\\bazaar.conf``
 

=== added directory 'tools/win32'
=== added file 'tools/win32/__init__.py'
--- tools/win32/__init__.py	1970-01-01 00:00:00 +0000
+++ tools/win32/__init__.py	2006-06-29 08:41:31 +0000
@@ -0,0 +1,1 @@
+# modules and utilities for making win32 installer

=== added file 'tools/win32/bazaar.url'
--- tools/win32/bazaar.url	1970-01-01 00:00:00 +0000
+++ tools/win32/bazaar.url	2006-06-29 08:41:31 +0000
@@ -0,0 +1,7 @@
+[InternetShortcut]
+URL=http://bazaar-vcs.org/
+Hotkey=0
+IconIndex=0
+IconFile=
+WorkingDirectory=
+ShowCommand=1

=== added file 'tools/win32/bzr-win32-bdist-postinstall.py'
--- tools/win32/bzr-win32-bdist-postinstall.py	1970-01-01 00:00:00 +0000
+++ tools/win32/bzr-win32-bdist-postinstall.py	2006-06-29 09:15:47 +0000
@@ -0,0 +1,59 @@
+# (c) Canonical Ltd, 2006
+# written by Alexander Belchenko for bzr project
+#
+# This script will be executed after installation of bzrlib package
+# and before installer exits.
+# All printed data will appear on the last screen of installation
+# procedure.
+# The main goal of this script is to create special batch file
+# launcher for bzr. Typical content of this batch file is:
+#  @python bzr %*
+#
+# This file works only on Windows 2000/XP. For win98 there is
+# should be "%1 %2 %3 %4 %5 %6 %7 %8 %9" instead of "%*".
+# Or even more complex thing.
+#
+# [bialix]: bzr de-facto does not support win98.
+#           Although it seems to work on. Sometimes.
+
+import os
+import sys
+
+if len(sys.argv) == 2 and sys.argv[1] == "-install":
+    # try to detect version number automatically
+    try:
+        import bzrlib
+    except ImportError:
+        ver = ''
+    else:
+        ver = bzrlib.__version__
+
+    ##
+    # XXX change message for something more appropriate
+    print """Bazaar-NG %s
+
+Congratulation! Bzr successfully installed.
+
+""" % ver
+
+    batch_path = "bzr.bat"
+    prefix = sys.prefix
+    try:
+        ##
+        # try to create
+        scripts_dir = os.path.join(prefix, "Scripts")
+        script_path = os.path.join(scripts_dir, "bzr")
+        python_path = os.path.join(prefix, "python.exe")
+        batch_str = "@%s %s %%*\n" % (python_path, script_path)
+        batch_path = script_path + ".bat"
+        f = file(batch_path, "w")
+        f.write(batch_str)
+        f.close()
+        file_created(batch_path)        # registering manually created files for
+                                        # auto-deinstallation procedure
+        ##
+        # inform user where batch launcher is.
+        print "Created:", batch_path
+        print "Use this batch file to run bzr"
+    except Exception, e:
+        print "ERROR: Unable to create %s: %s" % (batch_path, e)

=== added file 'tools/win32/bzr.iss.cog'
--- tools/win32/bzr.iss.cog	1970-01-01 00:00:00 +0000
+++ tools/win32/bzr.iss.cog	2006-06-29 08:41:31 +0000
@@ -0,0 +1,98 @@
+; Script for Inno Setup installer
+; [[[cog cog.outl('; This script created by Cog from bzr.iss.cog source') ]]]
+; [[[end]]]
+; Cog is http://www.nedbatchelder.com/code/cog/
+
+[Setup]
+AppName=Bazaar-NG (Bzr)
+
+; [[[cog
+; import bzrlib
+; try: 
+;     VERSION = bzrlib.__version__
+;     AppVerName = 'Bazaar-NG (Bzr) %s' % VERSION
+;     OutputBaseFilename = 'bzr-setup-%s' % VERSION
+; except:
+;     VERSION = ''
+;     AppVerName = 'Bazaar-NG (Bzr)'
+;     OutputBaseFilename = 'bzr-setup'
+;
+; cog.outl('AppVerName=%s' % AppVerName)
+; cog.outl('OutputBaseFilename=%s' % OutputBaseFilename)
+; ]]]
+AppVerName=Bazaar-NG (Bzr)
+OutputBaseFilename=bzr-setup
+; [[[end]]]
+
+DefaultDirName={pf}\Bazaar-NG
+DefaultGroupName=Bazaar-NG
+
+SolidCompression=yes
+
+OutputDir="..\"
+SourceDir="..\..\win32_bzr.exe"
+
+SetupIconFile="..\bzr.ico"
+
+VersionInfoCompany="Canonical Ltd."
+VersionInfoCopyright="Canonical Ltd., 2005-2006"
+VersionInfoDescription="Installer for stand-alone bzr.exe"
+; [[[cog
+; import bzrlib
+; version_number = []
+; for i in bzrlib.version_info[:3]:
+;     try:
+;         i = int(i)
+;     except ValueError:
+;         i = 0
+;     version_number.append(i)
+; # incremental build number
+; from tools.win32.file_version import *
+; try:
+;     version_prev = get_file_version(OutputBaseFilename + '.exe')
+; except (FileNotFound, VersionNotAvailable):
+;     pass
+; else:
+;     if version_number == list(version_prev[:3]):
+;         version_number.append((version_prev[-1]+1) % 65536)
+; version_str = '.'.join(str(i) for i in version_number)
+; cog.outl('VersionInfoVersion="%s"' % version_str)
+; ]]]
+; [[[end]]]
+
+AppComments="Bzr: Friendly distributed version control system"
+AppPublisher="Canonical Ltd."
+AppPublisherURL="http://www.bazaar-vcs.org"
+AppSupportURL="http://www.bazaar-vcs.org/BzrSupport"
+AppUpdatesURL="http://www.bazaar-vcs.org/WindowsDownloads"
+; [[[cog cog.outl('AppVersion=%s' % VERSION) ]]]
+; [[[end]]]
+
+ChangesEnvironment=yes
+
+[Files]
+Source: "*.*"; DestDir: "{app}"; Flags: ignoreversion;
+Source: "lib\*.*"; DestDir: "{app}\lib"; Flags: createallsubdirs ignoreversion recursesubdirs;
+Source: "doc\*.*"; DestDir: "{app}\doc"; Flags: createallsubdirs ignoreversion recursesubdirs;
+
+[Dirs]
+Name: "{userappdata}\bazaar\2.0"
+
+[Icons]
+Name: "{group}\Documentation index"; Filename: "{app}\doc\index.htm"; WorkingDir: "{app}\doc";
+Name: "{group}\Bazaar-NG Home Page"; Filename: "{app}\bazaar.url"; Comment: "http://www.bazaar-vcs.org";
+Name: "{group}\Start Bzr in cmd shell"; Filename: "{sys}\cmd.exe"; Parameters: "/K start_bzr.bat"; WorkingDir: "{app}"; IconFilename: "{app}\bzr.exe"; Comment: "Open new Bzr session";
+Name: "{group}\Uninstall Bzr"; Filename: "{uninstallexe}"; IconFileName: "{sys}\shell32.dll"; IconIndex: 101; Comment: "Remove Bzr completely";
+
+[Tasks]
+Name: Path; Description: "Add {app} directory to PATH environment variable";
+Name: Shell; Description: "Add Bzr context menu to shell";
+
+[Run]
+Filename: "{app}\bzr_postinstall.exe"; Parameters: "--start-bzr"; Flags: skipifdoesntexist runhidden;
+Filename: "{app}\bzr_postinstall.exe"; Parameters: "--check-mfc71"; Flags: skipifdoesntexist skipifsilent runhidden;
+Filename: "{app}\bzr_postinstall.exe"; Parameters: "--add-path"; Tasks: Path; Flags: skipifdoesntexist skipifsilent runhidden;
+Filename: "{app}\bzr_postinstall.exe"; Parameters: "--add-shell-menu"; Tasks: Shell; Flags: skipifdoesntexist skipifsilent runhidden;
+
+[UninstallRun]
+Filename: "{app}\bzr_postinstall.exe"; Parameters: "--delete-path --delete-shell-menu --silent"; Flags: skipifdoesntexist runhidden; 

=== added file 'tools/win32/bzr_postinstall.py'
--- tools/win32/bzr_postinstall.py	1970-01-01 00:00:00 +0000
+++ tools/win32/bzr_postinstall.py	2006-06-29 08:41:31 +0000
@@ -0,0 +1,270 @@
+# Copyright (C) 2005 by Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""bzr postinstall helper for win32 installation
+Written by Alexander Belchenko
+"""
+
+import os
+import sys
+
+
+##
+# CONSTANTS
+
+VERSION = "1.3.20060513"
+
+USAGE = """Bzr postinstall helper for win32 installation
+Usage: %s [options]
+
+OPTIONS:
+    -h, --help                  - help message
+    -v, --version               - version info
+
+    -n, --dry-run               - print actions rather than execute them
+    -q, --silent                - no messages for user
+
+    --start-bzr                 - update start_bzr.bat
+    --add-path                  - add bzr directory to environment PATH
+    --delete-path               - delete bzr directory to environment PATH
+    --add-shell-menu            - add shell context menu to start bzr session
+    --delete-shell-menu         - delete context menu from shell
+    --check-mfc71               - check if MFC71.DLL present in system
+""" % os.path.basename(sys.argv[0])
+
+##
+# INTERNAL VARIABLES
+
+(OK, ERROR) = range(2)
+VERSION_FORMAT = "%-50s%s"
+
+
+def main():
+    import getopt
+    import re
+    import _winreg
+
+    import locale
+    user_encoding = locale.getpreferredencoding() or 'ascii'
+
+    import ctypes
+
+    hkey_str = {_winreg.HKEY_LOCAL_MACHINE: 'HKEY_LOCAL_MACHINE',
+                _winreg.HKEY_CURRENT_USER: 'HKEY_CURRENT_USER',
+                _winreg.HKEY_CLASSES_ROOT: 'HKEY_CLASSES_ROOT',
+               }
+
+    dry_run = False
+    silent = False
+    start_bzr = False
+    add_path = False
+    delete_path = False
+    add_shell_menu = False
+    delete_shell_menu = False
+    check_mfc71 = False
+
+    try:
+        opts, args = getopt.getopt(sys.argv[1:], "hvnq",
+                                   ["help", "version",
+                                    "dry-run",
+                                    "silent",
+                                    "start-bzr",
+                                    "add-path",
+                                    "delete-path",
+                                    "add-shell-menu",
+                                    "delete-shell-menu",
+                                    "check-mfc71",
+                                   ])
+
+        for o, a in opts:
+            if o in ("-h", "--help"):
+                print USAGE
+                return OK
+            elif o in ("-v", "--version"):
+                print VERSION_FORMAT % (USAGE.splitlines()[0], VERSION)
+                return OK
+
+            elif o in ('-n', "--dry-run"):
+                dry_run = True
+            elif o in ('-q', '--silent'):
+                silent = True
+
+            elif o == "--start-bzr":
+                start_bzr = True
+            elif o == "--add-path":
+                add_path = True
+            elif o == "--delete-path":
+                delete_path = True
+            elif o == "--add-shell-menu":
+                add_shell_menu = True
+            elif o == "--delete-shell-menu":
+                delete_shell_menu = True
+            elif o == "--check-mfc71":
+                check_mfc71 = True
+
+    except getopt.GetoptError, msg:
+        print str(msg)
+        print USAGE
+        return ERROR
+
+    # message box from Win32API
+    MessageBoxA = ctypes.windll.user32.MessageBoxA
+    MB_OK = 0
+    MB_ICONERROR = 16
+    MB_ICONEXCLAMATION = 48
+
+    bzr_dir = os.path.dirname(sys.argv[0])
+
+    if start_bzr:
+        fname = os.path.join(bzr_dir, "start_bzr.bat")
+        if os.path.isfile(fname):
+            f = file(fname, "r")
+            content = f.readlines()
+            f.close()
+        else:
+            content = ["bzr.exe help\n"]
+
+        for ix in xrange(len(content)):
+            s = content[ix]
+            if re.match(r'.*(?<!\\)bzr\.exe([ "].*)?$',
+                        s.rstrip('\r\n'),
+                        re.IGNORECASE):
+                content[ix] = s.replace('bzr.exe',
+                                        '"%s"' % os.path.join(bzr_dir,
+                                                              'bzr.exe'))
+
+        if dry_run:
+            print "*** Write file: start_bzr.bat"
+            print "*** File content:"
+            print ''.join(content)
+        else:
+            f = file(fname, 'w')
+            f.write(''.join(content))
+            f.close()
+
+    if add_path or delete_path:
+        # find appropriate registry key:
+        # 1. HKLM\System\CurrentControlSet\Control\SessionManager\Environment
+        # 2. HKCU\Environment
+        keys = ((_winreg.HKEY_LOCAL_MACHINE, (r'System\CurrentControlSet\Control'
+                                              r'\Session Manager\Environment')),
+                (_winreg.HKEY_CURRENT_USER, r'Environment'),
+               )
+
+        hkey = None
+        for key, subkey in keys:
+            try:
+                hkey = _winreg.OpenKey(key, subkey, 0, _winreg.KEY_ALL_ACCESS)
+                try:
+                    path_u, type_ = _winreg.QueryValueEx(hkey, 'Path')
+                except WindowsError:
+                    if key != _winreg.HKEY_CURRENT_USER:
+                        _winreg.CloseKey(hkey)
+                        hkey = None
+                        continue
+                    else:
+                        path_u = u''
+                        type_ = _winreg.REG_SZ
+            except EnvironmentError:
+                continue
+            break
+
+        if hkey is None:
+            print "Cannot find appropriate registry key for PATH"
+        else:
+            path_list = [i for i in path_u.split(os.pathsep) if i != '']
+            f_change = False
+            for ix, item in enumerate(path_list[:]):
+                if item == bzr_dir:
+                    if delete_path:
+                        del path_list[ix]
+                        f_change = True
+                    elif add_path:
+                        print "*** Bzr already in PATH"
+                    break
+            else:
+                if add_path and not delete_path:
+                    path_list.append(bzr_dir.decode(user_encoding))
+                    f_change = True
+
+            if f_change:
+                path_u = os.pathsep.join(path_list)
+                if dry_run:
+                    print "*** Registry key %s\\%s" % (hkey_str[key], subkey)
+                    print "*** Modify PATH variable. New value:"
+                    print path_u
+                else:
+                    _winreg.SetValueEx(hkey, 'Path', 0, type_, path_u)
+                    _winreg.FlushKey(hkey)
+
+        if not hkey is None:
+            _winreg.CloseKey(hkey)
+
+    if add_shell_menu and not delete_shell_menu:
+        hkey = None
+        try:
+            hkey = _winreg.CreateKey(_winreg.HKEY_CLASSES_ROOT,
+                                     r'Folder\shell\bzr')
+        except EnvironmentError:
+            if not silent:
+                MessageBoxA(None,
+                            'Unable to create registry key for context menu',
+                            'EnvironmentError',
+                            MB_OK | MB_ICONERROR)
+
+        if not hkey is None:
+            _winreg.SetValue(hkey, '', _winreg.REG_SZ, 'Bzr Here')
+            hkey2 = _winreg.CreateKey(hkey, 'command')
+            _winreg.SetValue(hkey2, '', _winreg.REG_SZ,
+                             'cmd /K "%s"' % os.path.join(bzr_dir,
+                                                          'start_bzr.bat'))
+            _winreg.CloseKey(hkey2)
+            _winreg.CloseKey(hkey)
+
+    if delete_shell_menu:
+        try:
+            _winreg.DeleteKey(_winreg.HKEY_CLASSES_ROOT,
+                              r'Folder\shell\bzr\command')
+        except EnvironmentError:
+            pass
+
+        try:
+            _winreg.DeleteKey(_winreg.HKEY_CLASSES_ROOT,
+                              r'Folder\shell\bzr')
+        except EnvironmentError:
+            pass
+
+    if check_mfc71:
+        try:
+            ctypes.windll.LoadLibrary('mfc71.dll')
+        except WindowsError:
+            MessageBoxA(None,
+                        ("Library MFC71.DLL is not found on your system.\n"
+                         "This library needed for SFTP transport.\n"
+                         "If you need to work via SFTP you should download\n"
+                         "this library manually and put it to directory\n"
+                         "where Bzr installed.\n"
+                         "For detailed instructions see:\n"
+                         "http://bazaar-vcs.org/BzrOnPureWindows"
+                        ),
+                        "Warning",
+                        MB_OK | MB_ICONEXCLAMATION)
+
+    return OK
+
+
+if __name__ == "__main__":
+    sys.exit(main())

=== added file 'tools/win32/copy_docs.py'
--- tools/win32/copy_docs.py	1970-01-01 00:00:00 +0000
+++ tools/win32/copy_docs.py	2006-06-29 08:41:31 +0000
@@ -0,0 +1,15 @@
+import glob
+import os
+import shutil
+
+TGT_DIR = 'win32_bzr.exe/doc'
+
+if not os.path.exists(TGT_DIR):
+    os.makedirs(TGT_DIR)
+
+for i in glob.glob('doc/*.htm'):
+    shutil.copy(i, os.path.join('win32_bzr.exe', i))
+
+CSS = 'doc/default.css'
+if os.path.isfile(CSS):
+    shutil.copy(CSS, os.path.join('win32_bzr.exe', CSS))

=== added file 'tools/win32/file_version.py'
--- tools/win32/file_version.py	1970-01-01 00:00:00 +0000
+++ tools/win32/file_version.py	2006-06-29 08:41:31 +0000
@@ -0,0 +1,38 @@
+#!/usr/bin/python
+
+"""Get file version.
+Written by Alexander Belchenko, 2006
+"""
+
+import os
+
+import pywintypes   # from pywin32 (http://pywin32.sf.net)
+import win32api     # from pywin32 (http://pywin32.sf.net)
+
+
+__all__ = ['get_file_version', 'FileNotFound', 'VersionNotAvailable']
+__docformat__ = "restructuredtext"
+
+
+class FileNotFound(Exception):
+    pass
+
+class VersionNotAvailable(Exception):
+    pass
+
+
+def get_file_version(filename):
+    """Get file version (windows properties)
+    :param  filename:   path to file
+    :return:            4-tuple with 4 version numbers
+    """
+    if not os.path.isfile(filename):
+        raise FileNotFound
+
+    try:
+        version_info = win32api.GetFileVersionInfo(filename, '\\')
+    except pywintypes.error:
+        raise VersionNotAvailable
+
+    return (divmod(version_info['FileVersionMS'], 65536) +
+            divmod(version_info['FileVersionLS'], 65536))

=== added file 'tools/win32/start_bzr.bat'
--- tools/win32/start_bzr.bat	1970-01-01 00:00:00 +0000
+++ tools/win32/start_bzr.bat	2006-06-29 08:41:31 +0000
@@ -0,0 +1,31 @@
+@ECHO OFF
+
+REM    ******************************************************
+REM    **  You can change following environment variables  **
+REM    **  that affects on bzr behaviour                   **
+REM    ******************************************************
+
+REM If you don't add Bzr directory to system-wide PATH environment variable
+REM you can modify local PATH
+REM SET PATH=C:\Program Files\Bazaar-NG;%PATH%
+
+REM Change next line to set-up e-mail to identify yourself in bzr
+REM SET BZREMAIL=
+
+REM Change next line to specify editor to edit commit messages
+REM SET BZR_EDITOR=
+
+REM Change next line to tell where bzr should search for plugins
+REM SET BZR_PLUGIN_PATH=
+
+REM Change next line to use another home directory with bzr
+REM SET BZR_HOME=
+
+REM Change next line to control verbosity of .bzr.log
+REM SET BZR_DEBUG=30
+
+
+REM --------------------------------------------------------------------------
+
+bzr.exe help
+@ECHO ON

